# NOT RUN {
#####################################################
# Performing the l1-spectral clustering on the graph
#####################################################
data(ToyData)
# if desired, the number of clusters and representative elements can be provided,
# otherwise remove
results2 <- l1_spectralclustering(A = ToyData$A_hat, pen = "lasso")
results2$comm
# when desired, the number of clusters and representative elements can also be provided
# }
# NOT RUN {
results2 <- l1_spectralclustering(A = ToyData$A_hat, pen = "lasso",
k=2, elements = c(1,4))
# }
Run the code above in your browser using DataLab